@@ -18,6 +18,7 @@ use nng::options::Options;
 use nng::options::RecvTimeout;
 use nng::{Protocol, Socket};
 use std::io::Write;
+use std::net::IpAddr;
 use std::time::Duration;
 use std::time::Instant;
 use std::{env, thread, time};
@@ -506,7 +507,12 @@ pub fn init_log_with_params(module_name: &str, filter: Option<&str>, with_thread
     }
 }
 
-pub fn create_new_ticket(login: &str, user_id: &str, duration: i64, ticket: &mut Ticket, storage: &mut VStorage) {
+pub fn create_new_ticket(login: &str, user_id: &str, addr: &str, duration: i64, ticket: &mut Ticket, storage: &mut VStorage) {
+    if addr.parse::<IpAddr>().is_err() {
+        error!("fail create_new_ticket: invalid ip {}", addr);
+        return;
+    }
+
     let mut ticket_indv = Individual::default();
 
     ticket.result = ResultCode::FailStore;
@@ -520,6 +526,7 @@ pub fn create_new_ticket(login: &str, user_id: &str, duration: i64, ticket: &mut
 
     ticket_indv.add_string("ticket:login", login, Lang::NONE);
     ticket_indv.add_string("ticket:accessor", user_id, Lang::NONE);
+    ticket_indv.add_string("ticket:addr", addr, Lang::NONE);
 
     let now = Utc::now();
     let start_time_str = format!("{:?}", now.naive_utc());
@@ -540,7 +547,7 @@ pub fn create_new_ticket(login: &str, user_id: &str, duration: i64, ticket: &mut
         ticket.end_time = ticket.start_time + duration as i64 * 10_000_000;
 
         let end_time_str = format!("{:?}", NaiveDateTime::from_timestamp((ticket.end_time / 10_000 - TICKS_TO_UNIX_EPOCH) / 1_000, 0));
-        info!("create new ticket {}, login={}, user={}, start={}, end={}", ticket.id, ticket.user_login, ticket.user_uri, start_time_str, end_time_str);
+        info!("create new ticket {}, login={}, user={}, addr={}, start={}, end={}", ticket.id, ticket.user_login, ticket.user_uri, addr, start_time_str, end_time_str);
     } else {
         error!("fail store ticket {:?}", ticket)
     }
@@ -548,7 +555,7 @@ pub fn create_new_ticket(login: &str, user_id: &str, duration: i64, ticket: &mut
 
 pub fn create_sys_ticket(storage: &mut VStorage) -> Ticket {
     let mut ticket = Ticket::default();
-    create_new_ticket("veda", "cfg:VedaSystem", 90_000_000, &mut ticket, storage);
+    create_new_ticket("veda", "cfg:VedaSystem", "127.0.0.1", 90_000_000, &mut ticket, storage);
 
     if ticket.result == ResultCode::Ok {
         let mut sys_ticket_link = Individual::default();
